from . import Resource


class Circuit(Resource):
    """
        A representation of a circuit.

        Args:
            base (base): See :py:class:`nflex_connector_utils.resource.Resource` for common resource args.
            type_id (str): Type ID (optional)
            carrier (str): Carrier (optional)
            reference(str): Circuit reference (optional)
            endpoint_a (str): One endpoint for the circuit (optional)
            endpoint_b (str): The other endpoint for the circuit (optional)
    """  # noqa

    def __init__(self, type_id=None, carrier=None, reference=None,
                 endpoint_a=None, endpoint_b=None, **kwargs):
        super(Circuit, self).__init__(type='circuit', **kwargs)
        self._type_id = type_id
        self._carrier = carrier
        self._reference = reference
        self._endpoint_a = endpoint_a
        self._endpoint_b = endpoint_b

    def serialize(self):
        """Serialize the contents"""

        data = super(Circuit, self).serialize()
        data['details'] = {
            self.type: {
                "type_id": self._type_id,
                "carrier": self._carrier,
                "reference": self._reference,
                "endpoint_a": self._endpoint_a,
                "endpoint_b": self._endpoint_b,
            }
        }
        return data



from . import Resource


class ColoSpace(Resource):
    """
        A representation of a colo space.

        Args:
            base (base): See :py:class:`nflex_connector_utils.resource.Resource` for common resource args.
            power_allocation_w (int): Power Allocation in W (optional)
            type_id (str): Type ID (optional)
            colo_space_location (str): Location (optional)
            customer_name (str): Customer Name (optional)
            customer_label (str): Customer Label (optional)
            customer_description (str): Customer Description (optional)
            combination (str): Combination (optional)
    """  # noqa

    def __init__(self, power_allocation_w=None, type_id=None,
                 colo_space_location=None, customer_name=None,
                 customer_label=None, customer_description=None,
                 combination=None, **kwargs):
        super(ColoSpace, self).__init__(type='colo_space', **kwargs)
        self._power_allocation_w = power_allocation_w
        self._type_id = type_id
        self._colo_space_location = colo_space_location
        self._customer_name = customer_name
        self._customer_label = customer_label
        self._customer_description = customer_description
        self._combination = combination

    def serialize(self):
        """Serialize the contents"""

        data = super(ColoSpace, self).serialize()
        data['details'] = {
            self.type: {
                "power_allocation_w": self._power_allocation_w,
                "type_id": self._type_id,
                "colo_space_location": self._colo_space_location,
                "customer_name": self._customer_name,
                "customer_label": self._customer_label,
                "customer_description": self._customer_description,
                "combination": self._combination
            }
        }
        return data



from . import Resource


class Network(Resource):
    """
        A representation of a network

        Args:
            base (base): See :py:class:`nflex_connector_utils.resource.Resource` for common resource args.
    """  # noqa

    def __init__(self, **kwargs):
        super(Network, self).__init__(type='network', **kwargs)

    def serialize(self):
        """Serialize the contents"""

        data = super(Network, self).serialize()
        data['details'] = {'network': {}}
        return data
